# -*- coding:utf-8 -*-
# /usr/bin/env python
"""
Date: 2021/12/9 19:05
Desc: HTTP 模式主文件
"""
import json
import urllib.parse

import akshare as ak
from fastapi import FastAPI, Request

app = FastAPI()


@app.get("/api/{item_id}")
async def root(request: Request, item_id: str):
    """
    接收接口名称及其参数并返回 JSON 数据
    :param request: 请求信息
    :type request: Request
    :param item_id: 必选参数; 接口名; 比如 stock_zh_a_hist
    :type item_id: str
    :return: 指定 接口名称 和 参数 的数据
    :rtype: json
    """
    interface_list = dir(ak)
    decode_params = urllib.parse.unquote(str(request.query_params))
    if item_id not in interface_list:
        return {'error': '没有该接口'}
    eval_str = decode_params.replace("&", '", ').replace("=", '="') + '"'
    if not bool(request.query_params):
        try:
            temp_df = eval("ak." + item_id + f"()").to_json(orient='records', date_format='iso')
        except KeyError as e:
            return {'error': '参数错误'}
        return json.loads(temp_df)
    else:
        try:
            temp_df = eval("ak." + item_id + f"({eval_str})").to_json(orient='records', date_format='iso')
        except KeyError as e:
            return {'error': f'请输入正确的参数错误 {e} '}
        return json.loads(temp_df)



"""AKTools 是 AKShare 的 HTTP server 工具, 主要用于把 AKShare 的数据接口部署到本地从而通过 HTTP 访问"""

"""
Changelog

0.0.1:for test
0.0.2:FastAPI test
0.0.3:FastAPI deployment test
0.0.4:add docs
0.0.5:add automate package management
0.0.6:add automate package management success
0.0.7:add automate release test
0.0.8:add automate release test again
0.0.9:add automate success
0.0.10:fix: rename workflows
0.0.11:fix: README.md
0.0.12:fix: README.md
0.0.13:fix: test pull_request
0.0.14:fix: test master push tag
0.0.15:fix: update PYPI info
0.0.16:fix: update PYPI info
0.0.17:fix: update PYPI info
0.0.18:add: add params to interface
0.0.19:fix: rename file name
0.0.20:fix: rename api name
0.0.21:fix: rename api name
0.0.22:fix: fix core module
0.0.23:fix: fix core module
0.0.24:fix: fix chinese character params in api
0.0.25:test: test
0.0.26:test: test
0.0.27:test: test
0.0.28:test: test
0.0.29:test: test
0.0.30:add: add cmd arg parser
"""

__title__ = "AKTools"
__version__ = "0.0.30"
__author__ = "Albert King"



# -*- coding:utf-8 -*-
# /usr/bin/env python
"""
Date: 2021/12/9 19:09
Desc: HTTP 测试
"""
import requests
import pandas as pd


url = "http://127.0.0.1:8080/api/stock_financial_hk_analysis_indicator_em"
params = {
    "stock": "00700",
    "indicator": "年度"
}
r = requests.get(url, params=params)
temp_df = pd.DataFrame.from_dict(r.json())
print(temp_df)
